# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import enum

import winrt.system
from winrt import _winrt_windows_media

__all__ = [
    "AudioBufferAccessMode",
    "AudioProcessing",
    "MediaPlaybackAutoRepeatMode",
    "MediaPlaybackStatus",
    "MediaPlaybackType",
    "MediaTimelineControllerState",
    "SoundLevel",
    "SystemMediaTransportControlsButton",
    "SystemMediaTransportControlsProperty",
    "MediaTimeRange",
    "AudioBuffer",
    "AudioFrame",
    "AutoRepeatModeChangeRequestedEventArgs",
    "ImageDisplayProperties",
    "MediaControl",
    "MediaExtensionManager",
    "MediaMarkerTypes",
    "MediaProcessingTriggerDetails",
    "MediaTimelineController",
    "MediaTimelineControllerFailedEventArgs",
    "MusicDisplayProperties",
    "PlaybackPositionChangeRequestedEventArgs",
    "PlaybackRateChangeRequestedEventArgs",
    "ShuffleEnabledChangeRequestedEventArgs",
    "SystemMediaTransportControls",
    "SystemMediaTransportControlsButtonPressedEventArgs",
    "SystemMediaTransportControlsDisplayUpdater",
    "SystemMediaTransportControlsPropertyChangedEventArgs",
    "SystemMediaTransportControlsTimelineProperties",
    "VideoDisplayProperties",
    "VideoEffects",
    "VideoFrame",
    "IMediaExtension",
    "IMediaFrame",
    "IMediaMarker",
    "IMediaMarkers",
]

class AudioBufferAccessMode(enum.IntEnum):
    READ = 0
    READ_WRITE = 1
    WRITE = 2

class AudioProcessing(enum.IntEnum):
    DEFAULT = 0
    RAW = 1

class MediaPlaybackAutoRepeatMode(enum.IntEnum):
    NONE = 0
    TRACK = 1
    LIST = 2

class MediaPlaybackStatus(enum.IntEnum):
    CLOSED = 0
    CHANGING = 1
    STOPPED = 2
    PLAYING = 3
    PAUSED = 4

class MediaPlaybackType(enum.IntEnum):
    UNKNOWN = 0
    MUSIC = 1
    VIDEO = 2
    IMAGE = 3

class MediaTimelineControllerState(enum.IntEnum):
    PAUSED = 0
    RUNNING = 1
    STALLED = 2
    ERROR = 3

class SoundLevel(enum.IntEnum):
    MUTED = 0
    LOW = 1
    FULL = 2

class SystemMediaTransportControlsButton(enum.IntEnum):
    PLAY = 0
    PAUSE = 1
    STOP = 2
    RECORD = 3
    FAST_FORWARD = 4
    REWIND = 5
    NEXT = 6
    PREVIOUS = 7
    CHANNEL_UP = 8
    CHANNEL_DOWN = 9

class SystemMediaTransportControlsProperty(enum.IntEnum):
    SOUND_LEVEL = 0

MediaTimeRange = _winrt_windows_media.MediaTimeRange
AudioBuffer = _winrt_windows_media.AudioBuffer
AudioFrame = _winrt_windows_media.AudioFrame
AutoRepeatModeChangeRequestedEventArgs = _winrt_windows_media.AutoRepeatModeChangeRequestedEventArgs
ImageDisplayProperties = _winrt_windows_media.ImageDisplayProperties
MediaControl = _winrt_windows_media.MediaControl
MediaExtensionManager = _winrt_windows_media.MediaExtensionManager
MediaMarkerTypes = _winrt_windows_media.MediaMarkerTypes
MediaProcessingTriggerDetails = _winrt_windows_media.MediaProcessingTriggerDetails
MediaTimelineController = _winrt_windows_media.MediaTimelineController
MediaTimelineControllerFailedEventArgs = _winrt_windows_media.MediaTimelineControllerFailedEventArgs
MusicDisplayProperties = _winrt_windows_media.MusicDisplayProperties
PlaybackPositionChangeRequestedEventArgs = _winrt_windows_media.PlaybackPositionChangeRequestedEventArgs
PlaybackRateChangeRequestedEventArgs = _winrt_windows_media.PlaybackRateChangeRequestedEventArgs
ShuffleEnabledChangeRequestedEventArgs = _winrt_windows_media.ShuffleEnabledChangeRequestedEventArgs
SystemMediaTransportControls = _winrt_windows_media.SystemMediaTransportControls
SystemMediaTransportControlsButtonPressedEventArgs = _winrt_windows_media.SystemMediaTransportControlsButtonPressedEventArgs
SystemMediaTransportControlsDisplayUpdater = _winrt_windows_media.SystemMediaTransportControlsDisplayUpdater
SystemMediaTransportControlsPropertyChangedEventArgs = _winrt_windows_media.SystemMediaTransportControlsPropertyChangedEventArgs
SystemMediaTransportControlsTimelineProperties = _winrt_windows_media.SystemMediaTransportControlsTimelineProperties
VideoDisplayProperties = _winrt_windows_media.VideoDisplayProperties
VideoEffects = _winrt_windows_media.VideoEffects
VideoFrame = _winrt_windows_media.VideoFrame
IMediaExtension = _winrt_windows_media.IMediaExtension
IMediaFrame = _winrt_windows_media.IMediaFrame
IMediaMarker = _winrt_windows_media.IMediaMarker
IMediaMarkers = _winrt_windows_media.IMediaMarkers
